skillfed

triton-windows

A language and compiler for custom Deep Learning operations

triton-windows v3.7.1.post27 471.6K downloads/30d#6,479 on PyPI1,958
Permissive license Abandoned released

What it is and what it does

Triton-windows is a Windows-native fork of the Triton compiler, which allows you to write high-performance GPU kernels in Python and compile them just-in-time for NVIDIA GPUs. It bridges the gap between Python's ease of use and the performance demands of deep learning by letting you write custom operations that standard libraries don't cover, then compiling them directly to GPU code at runtime.

The package is designed specifically for Windows environments where the upstream Triton project did not have native support. It works with torch.compile and Triton's @triton.jit decorator, and passes all unit tests. Installation requires careful environment setup—you must ensure your Python version, PyTorch version, and GPU driver are aligned according to the documented compatibility matrix, and the package provides wheels only for Python 3.10–3.14 on Windows x86-64.

Use it for:

  • Accelerate custom deep learning operations on Windows by compiling hand-written GPU kernels instead of relying on standard libraries.
  • Optimize matrix multiplication, attention mechanisms, or other compute-intensive layers by writing Triton kernels tailored to your model's needs.
  • Use torch.compile with Triton on Windows to automatically fuse and compile operations into efficient GPU code.
  • Prototype and deploy GPU-accelerated algorithms on Windows without dropping to lower-level GPU programming or managing low-level GPU memory manually.

Worth the install?

AI-flagged interpretation of the facts on this page — verify before relying

Triton-windows is a Windows port of the Triton compiler that lets you write and compile custom GPU kernels for deep learning workloads on NVIDIA GPUs.

Yes, if you need to write custom GPU kernels on Windows and your NVIDIA GPU and PyTorch version are compatible. The permissive license and active wheel distribution make it straightforward to install. No, if you need ongoing maintenance and support—the original repository is archived, though development continues at https://github.com/triton-lang/triton-windows. Verify PyTorch and CUDA version compatibility before installing.

Install

triton-windows on PyPI

pip

pip install triton-windows

uv

uv add triton-windows

poetry

poetry add triton-windows

Installing triton-windows

Before you install

Medium install friction: platform-specific wheels for Windows (cp310–cp314), requires matching Python environment and GPU driver setup. Repository is archived; development has moved to https://github.com/triton-lang/triton-windows, but pip installation continues to work.

License in practice

Permissive license (MIT) means you can use this package freely in commercial and private projects without restriction.

Quickstart

pip install triton-windows
import triton
@triton.jit
def kernel(x_ptr, output_ptr, n_elements, BLOCK_SIZE: tl.constexpr):
    pid = tl.program_id(axis=0)
    block_start = pid * BLOCK_SIZE
    offsets = block_start + tl.arange(0, BLOCK_SIZE)
    mask = offsets < n_elements
    x = tl.load(x_ptr + offsets, mask=mask)
    tl.store(output_ptr + offsets, x, mask=mask)

Requires Windows 10 or 11, NVIDIA GPU with supported compute capability, matching PyTorch version (e.g., PyTorch 2.7 requires Triton 3.3), and correct Python environment setup (embedded, system-wide, conda, or venv).

Verify before relying

  • Whether AMD GPU support via the referenced pull request is production-ready or experimental.
  • Current status and stability of free-threaded Python (3.13t/3.14t) support on Windows.
  • Whether Proton profiler limitations affect your profiling workflow.
  • Specific GPU compute capability requirements for different Triton versions on Windows.

Package facts

License not declared (permissive)
Python support supports the current Python release (<3.15,>=3.10)
Install friction medium — platform-specific wheel
Runtime dependencies 1 — importlib-metadata
Maintenance abandoned — 54 days since the last release
Last repo commit (repository archived)
First released
Downloads 471,577/month — #6,479 on PyPI (30-day window, as of 2026-08-14)
Known vulnerabilities none known (OSV.dev, checked 2026-08-14)

Evidence: triton_windows-3.7.1.post27-cp310-cp310-win_amd64.whl; triton_windows-3.7.1.post27-cp311-cp311-win_amd64.whl; triton_windows-3.7.1.post27-cp312-cp312-win_amd64.whl; triton_windows-3.7.1.post27-cp313-cp313-win_amd64.whl; triton_windows-3.7.1.post27-cp314-cp314-win_amd64.whl

Keywords: Compiler, Deep Learning

Development Status :: 4 - BetaIntended Audience :: DevelopersLicense :: OSI Approved :: MIT LicenseProgramming Language :: Python :: 3.10Programming Language :: Python :: 3.11Programming Language :: Python :: 3.12Programming Language :: Python :: 3.13Programming Language :: Python :: 3.14Topic :: Software Development :: Build Tools

Tags

GPU kernel compiler windowstriton deep learning compilercustom GPU kernels pythonGPU acceleration windowstriton JIT compilation
gpu-accelerationkernel-compilationwindows-native

More Build Tools packages

Further reading